==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/ar.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "لايمكنك إزالة إذن القراءة الخاص بك.",
    "Team folders" : "مُجلّدات الفريق",
    "Admin configured folders shared with everyone in a team" : "مُجلّدات كوّنها المُشرف لتكون مشتركة بين جميع أعضاء الفريق ",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "مُجلَّدات تمَّ تكوينها بواسطة المشرف والذي قام بمشاركتها مع جميع أعضاء الفريق. \n\nيمكن تكوين المجلدات من *مجلدات الفريق Team folders* في إعدادات الإدارة. \n\nبعد إنشاء مجلد، يمكن للمسؤول منح حق الوصول إليه لفريق واحد أو أكثر، والتحكم في أذونات الكتابة/المشاركة الخاصة بهم وتعيين حصة تخزينية للمجلد. \n\nاعتباراً من الاصدار العاشر من \"نكست كلاود هَب\" Hub 10/Nextcloud 31، يجب أن يكون المسؤول جزءاً من الفريق حتى يتمكن من تعيين مجلد عامٍّ له.",
    "Unset" : "غير محدد",
    "Denied (Inherited permission)" : "مرفوض (إذن موروث)",
    "Allowed (Inherited permission)" : "مسموح (إذن موروث)",
    "Denied" : "مرفوض",
    "Allowed" : "مسموح",
    "Access denied" : "الوصول ممنوع",
    "Access allowed" : "الوصول مُتاح",
    "Inherit permission" : "إذن موروث",
    "Deny" : "رفض",
    "Allow" : "سماح",
    "Group" : "مجموعة",
    "Team" : "الفريق",
    "Team folder" : "مُجلّد للفريق",
    "Read" : "قراءة",
    "Write" : "كتابة",
    "Create" : "إنشاء",
    "Delete" : "حذف ",
    "Share" : "مشاركة ",
    "You" : "أنت",
    "Remove access rule" : "حذف شرط الوصول",
    "Add advanced permission rule" : "إضافة شرط وصول مُتقدّم",
    "Select a user or group" : "اختر مجموعة مستخدمين",
    "Open Team folder" : "فتح مجلد للفريق",
    "Permission denied. User does not have sufficient permissions." : "تمّ رفض منح الإذن. المستخدم ليس لديه الأذونات الكافية",
    "Unexpected status from server" : "حالة غير متوقعة من الخادم",
    "List of Team folders." : "قائمة بمجلدات الفريق",
    "No Team folders yet" : "لاتوجد أي مجلدات للفريق بعدُ",
    "Team folders will show up here" : "مجلدات الفريق سوف تُعرَض هنا",
    "Add group" : "إضافة فريق",
    "Default" : "التلقائي",
    "Unlimited" : "غير محدود",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "هل أنت متأكد أنك تريد حذف \"{folderName}\" و كل الملفات التي بداخله؟ لا يمكن التراجع عن هذه العملية لاحقاً.",
    "Delete \"{folderName}\"?" : "حذف المجلد  \"{folderName}\"؟",
    "Team folder admin delegation" : "تفويض مشرف على مجلدات الفريق",
    "They will have access to all Team folders." : "سوف يكون لهم حق الوصول إلى كل مجلدات الفريق.",
    "They will only have access to Team folders for which they have advanced permissions." : "سوف يكون لهم فقط حق الوصول إلى مجلدات الفريق التي لديهم أذونات متقدمة لها.",
    "Group or team" : "المجموعة أو الفريق",
    "Folder name" : "اسم المجلد",
    "Quota" : "الحصة",
    "Advanced Permissions" : "أذونات وصول متقدمة",
    "Previous" : "السابق",
    "Next" : "التالي",
    "User" : "مستخدم",
    "Unknown" : "غير معروف",
    "Users/groups that can manage" : "المستخدمون والمجموعات التي يديرها",
    "None" : "لا شيء",
    "No other groups or teams available" : "لا توجد مجموعات أو فِرق أخرى مُتاحة",
    "No other groups available" : "لا توجد مجموعات أخرى مُتاحة",
    "{displayName} (team)" : "{displayName} (فريق)",
    "Add group or team" : "إضافة مجموعة أو فريق",
    "{size} used" : "تم استهلاك{size} ",
    "You can not remove your own read permission." : "لايمكنك إزالة إذن القراءة الخاص بك.",
    "Group folders" : "مجلدات المجموعة",
    "Admin configured folders shared with everyone in a group" : "مجلدات المجموعة مشتركة بين كل أعضاء المجموعة و يديرها المدير",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "المجلدات التي يقوم المدير بتكوينها تتم مشاركتها مع جميع أعضاء المجموعة. يمكن تكوين المجلدات من *مجلدات المجموعة Group folders* في إعدادات المدير. بعد إنشاء المجلد، يمكن للمدير  منح حق الوصول إليه لمجموعة واحدة أو أكثر، و كذلك التحكم في أذونات الكتابة و المشاركة الخاصة بهم وتعيين حصة تخزينية للمجلد.",
    "Group folder" : "مجلد مجموعة",
    "Open group folder" : "فتح مجلد المجموعة",
    "List of group folders." : "قائمة مجلدات المجموعة",
    "No group folders yet" : "لا توجد أي مجلدات مجموعة حتى الآن",
    "Group folders will show up here" : "مجلدات المجموعة ستظهر هنا",
    "Group folder admin delegation" : "تفويض صلاحيات مدير مجلد مجموعة",
    "They will have access to all group folders." : "سوف يمكنهم الوصول إلى جميع مجلدات المجموعة",
    "They will only have access to group folders for which they have advanced permissions." : "سوف يمكنهم الوصول فقط إلى مجلدات المجموعة التي لديهم أذونات وصول متقدمة إليها.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "قام المسؤول بتكوين المجلدات المشتركة بين جميع أعضاء الفريق. يمكن تكوين المجلدات من *مجلدات الفريق\"  Team Folders في إعدادات المُشرف. بعد إنشاء المجلد، يمكن للمسؤول منح حق الوصول إلى المجلد لفريق واحد أو أكثر، والتحكم في أذونات الكتابة أو المشاركة الخاصة بهم وتعيين حصة تخزينية للمُجلّد."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/ar.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "لايمكنك إزالة إذن القراءة الخاص بك.",
    "Team folders" : "مُجلّدات الفريق",
    "Unset" : "غير محدد",
    "Denied (Inherited permission)" : "مرفوض (إذن موروث)",
    "Allowed (Inherited permission)" : "مسموح (إذن موروث)",
    "Denied" : "مرفوض",
    "Allowed" : "مسموح",
    "Access denied" : "الوصول ممنوع",
    "Access allowed" : "الوصول مُتاح",
    "Inherit permission" : "إذن موروث",
    "Deny" : "رفض",
    "Allow" : "سماح",
    "Group" : "مجموعة",
    "Team" : "الفريق",
    "Team folder" : "مُجلّد للفريق",
    "Read" : "قراءة",
    "Write" : "كتابة",
    "Create" : "إنشاء",
    "Delete" : "حذف ",
    "Share" : "مشاركة ",
    "You" : "أنت",
    "Remove access rule" : "حذف شرط الوصول",
    "Add advanced permission rule" : "إضافة شرط وصول مُتقدّم",
    "Select a user or group" : "اختر مجموعة مستخدمين",
    "Open Team folder" : "فتح مجلد للفريق",
    "Permission denied. User does not have sufficient permissions." : "تمّ رفض منح الإذن. المستخدم ليس لديه الأذونات الكافية",
    "Unexpected status from server" : "حالة غير متوقعة من الخادم",
    "List of Team folders." : "قائمة بمجلدات الفريق",
    "No Team folders yet" : "لاتوجد أي مجلدات للفريق بعدُ",
    "Team folders will show up here" : "مجلدات الفريق سوف تُعرَض هنا",
    "Add group" : "إضافة فريق",
    "Default" : "التلقائي",
    "Unlimited" : "غير محدود",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "هل أنت متأكد أنك تريد حذف \"{folderName}\" و كل الملفات التي بداخله؟ لا يمكن التراجع عن هذه العملية لاحقاً.",
    "Delete \"{folderName}\"?" : "حذف المجلد  \"{folderName}\"؟",
    "Team folder admin delegation" : "تفويض مشرف على مجلدات الفريق",
    "They will have access to all Team folders." : "سوف يكون لهم حق الوصول إلى كل مجلدات الفريق.",
    "They will only have access to Team folders for which they have advanced permissions." : "سوف يكون لهم فقط حق الوصول إلى مجلدات الفريق التي لديهم أذونات متقدمة لها.",
    "Group or team" : "المجموعة أو الفريق",
    "Folder name" : "اسم المجلد",
    "Quota" : "الحصة",
    "Advanced Permissions" : "أذونات وصول متقدمة",
    "Previous" : "السابق",
    "Next" : "التالي",
    "User" : "مستخدم",
    "Unknown" : "غير معروف",
    "Users/groups that can manage" : "المستخدمون والمجموعات التي يديرها",
    "None" : "لا شيء",
    "No other groups or teams available" : "لا توجد مجموعات أو فِرق أخرى مُتاحة",
    "No other groups available" : "لا توجد مجموعات أخرى مُتاحة",
    "{displayName} (team)" : "{displayName} (فريق)",
    "Add group or team" : "إضافة مجموعة أو فريق",
    "{size} used" : "تم استهلاك{size} ",
    "You can not remove your own read permission." : "لايمكنك إزالة إذن القراءة الخاص بك.",
    "Group folders" : "مجلدات المجموعة",
    "Admin configured folders shared with everyone in a group" : "مجلدات المجموعة مشتركة بين كل أعضاء المجموعة و يديرها المدير",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "المجلدات التي يقوم المدير بتكوينها تتم مشاركتها مع جميع أعضاء المجموعة. يمكن تكوين المجلدات من *مجلدات المجموعة Group folders* في إعدادات المدير. بعد إنشاء المجلد، يمكن للمدير  منح حق الوصول إليه لمجموعة واحدة أو أكثر، و كذلك التحكم في أذونات الكتابة و المشاركة الخاصة بهم وتعيين حصة تخزينية للمجلد.",
    "Group folder" : "مجلد مجموعة",
    "Open group folder" : "فتح مجلد المجموعة",
    "List of group folders." : "قائمة مجلدات المجموعة",
    "No group folders yet" : "لا توجد أي مجلدات مجموعة حتى الآن",
    "Group folders will show up here" : "مجلدات المجموعة ستظهر هنا",
    "Group folder admin delegation" : "تفويض صلاحيات مدير مجلد مجموعة",
    "They will have access to all group folders." : "سوف يمكنهم الوصول إلى جميع مجلدات المجموعة",
    "They will only have access to group folders for which they have advanced permissions." : "سوف يمكنهم الوصول فقط إلى مجلدات المجموعة التي لديهم أذونات وصول متقدمة إليها.",
    "Admin configured folders shared with everyone in a team" : "مُجلّدات كوّنها المُشرف لتكون مشتركة بين جميع أعضاء الفريق ",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "قام المسؤول بتكوين المجلدات المشتركة بين جميع أعضاء الفريق. يمكن تكوين المجلدات من *مجلدات الفريق\"  Team Folders في إعدادات المُشرف. بعد إنشاء المجلد، يمكن للمسؤول منح حق الوصول إلى المجلد لفريق واحد أو أكثر، والتحكم في أذونات الكتابة أو المشاركة الخاصة بهم وتعيين حصة تخزينية للمُجلّد.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "مُجلَّدات تمَّ تكوينها بواسطة المشرف والذي قام بمشاركتها مع جميع أعضاء الفريق. \n\nيمكن تكوين المجلدات من *مجلدات الفريق Team folders* في إعدادات الإدارة. \n\nبعد إنشاء مجلد، يمكن للمسؤول منح حق الوصول إليه لفريق واحد أو أكثر، والتحكم في أذونات الكتابة/المشاركة الخاصة بهم وتعيين حصة تخزينية للمجلد. \n\nاعتباراً من الاصدار العاشر من \"نكست كلاود هَب\" Hub 10/Nextcloud 31، يجب أن يكون المسؤول جزءاً من الفريق حتى يتمكن من تعيين مجلد عامٍّ له."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
